{% extends 'allianceauth/base-bs5.html' %}
{% load i18n %}
{% load navactive %}

{% block page_title %}{{ page_title }} - {% translate "Leave of Absence" %}{% endblock %}

{% block header_nav_brand %}{% translate "Leave of Absences" %}{% endblock %}

{% block header_nav_collapse_left %}
    <li class="nav-item">
        <a class="nav-link {% navactive request 'inactivity:my_requests' %}" href="{% url 'inactivity:my_requests' %}">
                {% translate 'My Requests' %}
        </a>
    </li>

    {% if perms.inactivity.manage_leave %}
        <li class="nav-item">
            <a class="nav-link {% navactive request 'inactivity:manage_requests' %}" href="{% url 'inactivity:manage_requests' %}">
                {% translate 'Manage requests' %}
                {% if unapproved_count > 0 %}
                    <span class="badge text-bg-success badge-nav">{{ unapproved_count }}</span>
                {% endif %}
             </a>
        </li>

        <li class="nav-item">
            <a class="nav-link {% navactive request 'inactivity:inactive_users' %}" href="{% url 'inactivity:inactive_users' %}">
                    {% translate 'Inactive users' %}
            </a>
        </li>
    {% endif %}

{% endblock header_nav_collapse_left %}

{% block header_nav_user_character_control %}
    {% comment %}
        This block is left empty intentionally to disable defaults.
    {% endcomment %}
{% endblock %}

{% block content %}
    <h2>{{ page_title }}</h2>
    {% block details %}{% endblock %}
{% endblock %}
