{% extends 'inactivity/base.html' %}
{% load i18n %}
{% load humanize %}
{% load static %}
{% load bootstrap %}

{% block details %}
    <div class="card card-primary">
        <div class="card-body" style="min-height: 100px;">
            <h5 class="card-title">Deny Request</h5>
            <form role="form" method="POST" action="{% url 'inactivity:deny_loa_request' loa_request.pk %}">
                {% csrf_token %}
                {{ form|bootstrap }}
                <div class="d-flex justify-content-between">
                    <a class="btn btn-secondary float-left" href="{% url 'inactivity:manage_requests' %}">
                        {% translate "Cancel" %}
                    </a>
                    <button type="submit" class="btn btn-danger float-right">
                        Deny
                    </button>
                </div>
            </form>
        </div>
    </div>
{% endblock %}
